OC.L10N.register(
    "settings",
    {
    "Private" : "Privé",
    "Only visible to people matched via phone number integration through Talk on mobile" : "Alleen zichtbaar voor mensen die via telefoonnummerintegratie gematcht zijn voor Talk op mobiel",
    "Local" : "Lokaal",
    "Only visible to people on this instance and guests" : "Alleen zichtbaar voor gebruikers op deze server en gasten",
    "Federated" : "Gefedereerd",
    "Only synchronize to trusted servers" : "Alleen synchroniseren met vertrouwde servers",
    "Published" : "Gepubliceerd",
    "Synchronize to trusted servers and the global and public address book" : "Synchroniseren met vertrouwde servers en het wereldwijde en openbare adresboek",
    "Verify" : "Verifiëren",
    "Verifying …" : "Verifiëren...",
    "Unable to change password" : "Kan wachtwoord niet wijzigen",
    "Very weak password" : "Zeer zwak wachtwoord",
    "Weak password" : "Zwak wachtwoord",
    "So-so password" : "Matig wachtwoord",
    "Good password" : "Goed wachtwoord",
    "Strong password" : "Sterk wachtwoord",
    "Groups" : "Groepen",
    "Group list is empty" : "Groepenlijst is leeg",
    "Unable to retrieve the group list" : "Kan groepenoverzicht niet ophalen",
    "{actor} added you to group {group}" : "{actor} voegde je toe aan groep {group}",
    "You added {user} to group {group}" : "Je hebt gebruiker {user} aan de groep {group} toegevoegd.",
    "{actor} added {user} to group {group}" : "{actor} voegde {user} toe aan groep {group}",
    "An administrator added you to group {group}" : "Een beheerder heeft je aan de groep {group} toegevoegd.",
    "An administrator added {user} to group {group}" : "Een beheerder heeft gebruiker {user} aan groep {group} toegevoegd.",
    "{actor} removed you from group {group}" : "{actor} verwijderde jou uit groep {group}",
    "You removed {user} from group {group}" : "Je hebt gebruiker {user} uit de groep {group} verwijderd.",
    "{actor} removed {user} from group {group}" : "{actor} verwijderde {user} uit groep {group}",
    "An administrator removed you from group {group}" : "Een beheerder heeft u uit groep {group} verwijderd.",
    "An administrator removed {user} from group {group}" : "Een beheerder verwijderde {user} uit groep {group}",
    "Your <strong>group memberships</strong> were modified" : "Je <strong>groepslidmaatschap</strong> werd gewijzigd",
    "{actor} changed your password" : "{actor} heeft je wachtwoord aangepast",
    "You changed your password" : "Je hebt je wachtwoord aangepast",
    "Your password was reset by an administrator" : "Je wachtwoord is hersteld door een beheerder",
    "Your password was reset" : "Je wachtwoord is opnieuw ingesteld",
    "{actor} changed your email address" : "{actor} wijzigde je e-mailadres",
    "You changed your email address" : "Je wijzigde je e-mailadres",
    "Your email address was changed by an administrator" : "Je e-mailadres is gewijzigd door een beheerder",
    "You created an app password for a session named \"{token}\"" : "Je creëerde een app wachtwoord voor een sessie genaamd \"{token}\"",
    "An administrator created an app password for a session named \"{token}\"" : "Een beheerder maakte een app wachtwoord voor een sessie met de naam \"{token}\"",
    "You deleted app password \"{token}\"" : "Je verwijderde appwachtwoord \"{token}\"",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "Je hernoemde appwachtwoord \"{token}\" naar \"{newToken}\"",
    "You granted filesystem access to app password \"{token}\"" : "Je hebt toegang tot het bestandssysteem verleend aan appwachtwoord \"{token}\"",
    "You revoked filesystem access from app password \"{token}\"" : "Je hebt toegang tot het bestandssysteem ingetrokken voor appwachtwoord \"{token}\"",
    "Security" : "Beveiliging",
    "You successfully logged in using two-factor authentication (%1$s)" : "Je bent succesvol ingelogd via tweetrapsauthenticatie (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Een inlogpoging via tweetrapsauthenticatie is mislukt (%1$s)",
    "Remote wipe was started on %1$s" : "Wissen op afstand gestart op %1$s",
    "Remote wipe has finished on %1$s" : "Wissen op afstand voltooid op %1$s",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Je <strong>wachtwoord</strong> of <strong>e-mailadres</strong> is gewijzigd",
    "Settings" : "Instellingen",
    "Could not remove app." : "Kon app niet verwijderen",
    "Could not update app." : "Kon app niet updaten",
    "Wrong password" : "Onjuist wachtwoord",
    "Unable to change personal password" : "Kan persoonlijk wachtwoord niet wijzigen",
    "Saved" : "Opgeslagen",
    "No Login supplied" : "Geen login opgegeven",
    "Unable to change password. Password too long." : "Kan wachtwoord niet wijzigen. Wachtwoord te lang.",
    "Authentication error" : "Authenticatiefout",
    "Please provide an admin recovery password; otherwise, all account data will be lost." : "Voer een beheerdersherstelwachtwoord in, anders zullen alle account gegevens verloren gaan.",
    "Wrong admin recovery password. Please check the password and try again." : "Onjuist beheerdersherstelwachtwoord. Controleer het wachtwoord en probeer het opnieuw.",
    "Backend does not support password change, but the encryption of the account key was updated." : "Backend ondersteunt geen wachtwoordwijzigingen, maar de versleuteling van de accountsleutel is bijgewerkt.",
    "Administrator documentation" : "Beheerdersdocumentatie",
    "User documentation" : "Gebruikersdocumentatie",
    "Nextcloud help overview" : "Nextcloud hulpoverzicht",
    "Invalid SMTP password." : "Ongeldig SMTP wachtwoord",
    "Email setting test" : "E-mailinstellingen test",
    "Well done, %s!" : "Goed gedaan, %s!",
    "If you received this email, the email configuration seems to be correct." : "Als je deze e-mail hebt ontvangen, dan lijken de e-mailinstellingen correct.",
    "Email could not be sent. Check your mail server log" : "Er kon geen e-mail verstuurd worden. Controleer je server log files",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Er ontstond een probleem bij het versturen van de e-mail. Controleer je instellingen.  (Fout: %s)",
    "You need to set your account email before being able to send test emails. Go to %s for that." : "Je moet je e-mail voor je account instellen voordat je e-mail kan versturen. Ga hiervoor naar %s.",
    "Recently active" : "Recent actief",
    "Disabled accounts" : "Uitgeschakelde accounts",
    "Invalid account" : "Ongeldig account",
    "Invalid mail address" : "Ongeldig e-mailadres",
    "Settings saved" : "Instellingen opgeslagen",
    "Unable to change full name" : "Kan de volledige naam niet wijzigen",
    "Unable to change email address" : "Kan e-mailadres niet wijzigen",
    "Unable to set invalid phone number" : "Kon geen geldig telefoonnummer instellen",
    "Unable to set invalid website" : "Kan geen ongeldig website instellen",
    "Some account data was invalid" : "Sommige accountgegevens ongeldig",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Om je Twitter-account te verifiëren moet je de volgende tweet op Twitter plaatsen (zorg dat je het plaatst zonder regelafbreking):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Om je website te verifiëren voeg de inhoud toe binnen de web-root van je server '.well-known/CloudIdVerificationCode.txt' (zorg dat de tekst op één regel staat):",
    "%1$s changed your password on %2$s." : "%1$swijzigde je wachtwoord op %2$s.",
    "Your password on %s was changed." : "Je wachtwoord op %s is gewijzigd.",
    "Your password on %s was reset by an administrator." : "Je wachtwoord op %s werd hersteld door een beheerder.",
    "Your password on %s was reset." : "Je wachtwoord op %s is opnieuw ingesteld",
    "Password for %1$s changed on %2$s" : "Wachtwoord voor %1$s gewijzigd op %2$s",
    "Password changed for %s" : "Wachtwoord gewijzigd voor %s",
    "If you did not request this, please contact an administrator." : "Als je dat niet aanvroeg, neem dan contact op met een beheerder.",
    "Your email address on %s was changed." : "Je e-mailadres op %sis gewijzigd.",
    "Your email address on %s was changed by an administrator." : "Je e-mailadres op %s is gewijzigd door een beheerder.",
    "Email address for %1$s changed on %2$s" : "E-mailadres voor %1$s gewijzigd op %2$s",
    "Email address changed for %s" : "E-mailadres gewijzigd voor %s",
    "The new email address is %s" : "Het nieuwe e-mailadres is %s",
    "Your %s account was created" : "Je %s account is aangemaakt",
    "Welcome aboard" : "Welkom aan boord",
    "Welcome aboard %s" : "Welkom aan boord %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "Welkom bij je %s account; je kunt nu je bestanden toevoegen en veilig delen.",
    "Your Login is: %s" : "Je login is: %s",
    "Set your password" : "Stel je wachtwoord in",
    "Go to %s" : "Ga naar %s",
    "Install Client" : "Installeer Client",
    "Logged in account must be a subadmin" : "Aangemeld account moet een subadmin zijn",
    "Apps" : "Apps",
    "Personal" : "Persoonlijk",
    "Administration" : "Beheer",
    "Users" : "Gebruikers",
    "Additional settings" : "Aanvullende instellingen",
    "Artificial Intelligence" : "Artificiële Intelligentie",
    "Administration privileges" : "Beheerdersprivileges",
    "Groupware" : "Groupware",
    "Overview" : "Overzicht",
    "Basic settings" : "Basis-instellingen",
    "Sharing" : "Delen",
    "Availability" : "Beschikbaarheid",
    "Calendar" : "Agenda",
    "Personal info" : "Persoonlijke info",
    "Mobile & desktop" : "Mobiel & desktop",
    "Email server" : "E-mailserver",
    "Security & setup warnings" : "Beveiligings- en instellingswaarschuwingen",
    "Background jobs" : "Achtergrondtaken",
    "Unlimited" : "Ongelimiteerd",
    "Verifying" : "Controleer",
    "Allowed admin IP ranges" : "Toegestane beheerder IP-reeksen",
    "Admin IP filtering isn’t applied." : "Beheerder IP-filtering is niet toegepast.",
    "Configuration key \"%1$s\" expects an array (%2$s found). Admin IP range validation will not be applied." : "Configuratiesleutel \"%1$s\" verwacht een array (%2$s gevonden). Validatie van beheerder IP-bereik wordt niet toegepast.",
    "Configuration key \"%1$s\" contains invalid IP range(s): \"%2$s\"" : "Configuratiesleutel \"%1$s\" bevat ongeldig(e) IP-bereik(en): \"%2$s\"",
    "Admin IP filtering is correctly configured." : "Beheerder IP-filtering is juist geconfigureerd.",
    "App directories owner" : "Eigenaar app mappen",
    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:\n%s" : "Sommige app mappen zijn eigendom van een andere gebruiker dan op de webserver . Dat kan het geval zijn als apps handmatig zijn geïnstalleerd. Controleer de machtigingen van de volgende app mappen:\n%s",
    "App directories have the correct owner \"%s\"" : "App mappen hebben de juiste eigenaar \"%s\"",
    "Brute-force Throttle" : "Bruteforce begrenzing",
    "Your remote address could not be determined." : "Je remote adres kon niet bepaald worden",
    "Your remote address was identified as \"%s\" and is brute-force throttled at the moment slowing down the performance of various requests. If the remote address is not your address this can be an indication that a proxy is not configured correctly." : "Je remote adres is geregistreerd als \"%s\" en wordt op dit moment afgeremd ter bescherming van bruteforce aanvallen. Dit verlaagt de performantie van verschillende aanvragen. Als het remote adres niet uw adres is kan dit wijzen op een verkeerd ingestelde proxy. ",
    "Your remote address \"%s\" is not brute-force throttled." : "Je remote adres %s is niet bruteforce begrensd.",
    "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Je datamap en je bestanden zijn waarschijnlijk vanaf het internet bereikbaar.  Het .htaccess-bestand werkt niet. We raden ten zeerste aan aan om je webserver zodanig te configureren, dat de datadirectory niet bereikbaar is vanaf het internet of om je datadirectory te verplaatsen naar een locatie buiten de document-root van de webserver.",
    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "De database mist een paar optionele kolommen. Omdat het toevoegen van kolommen op grote tabellen veel tijd kan kosten, zijn ze niet automatisch gecreëerd, omdat dat optioneel kan. Door het draaien van \"occ db:add-missing-columns\" kunnen deze kolommen handmatig worden toegevoegd terwijl de server blijft draaien.  Als de kolommen zijn toegevoegd, zullen bepaalde functionaliteiten veel sneller of gemakkelijker plaatsvinden.",
    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "De database mist enkele primaire sleutels. Omdat het toevoegen van primaire sleutels aan grote tabellen enige tijd kan duren, werden ze niet automatisch toegevoegd. Door \"occ db:add-missing-primary-keys\" uit te voeren, kunnen die ontbrekende primaire sleutels handmatig worden toegevoegd terwijl de server blijft draaien.",
    "This instance is running in debug mode. Only enable this for local development and not in production environments." : "Deze instantie draait in debug modus. Gelieve deze modus enkel te gebruiken voor lokale ontwikkeling, en niet in productie omgevingen.",
    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "Deze server heeft geen werkende internetverbinding: meerdere endpoints kunnen niet worden bereikt. Dat betekent dat sommige functies, zoals het gebruik van externe opslag, notificaties over updates of installatie van apps van derde partijen niet werken. Ook het benaderen van bestanden vanaf een remote locatie en het versturen van notificatie emails kan mislukken. We adviseren om de internetverbinding voor deze server in te schakelen als je alle functies wilt gebruiken.",
    "Disabled" : "Uitgeschakeld",
    "The old server-side-encryption format is enabled. We recommend disabling this." : "Het oude server-side-encryptie formaat is ingeschakeld. We raden aan om dit uit te schakelen.",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "De PHP functie \"set_time_limit\" is niet beschikbaar. Dit kan erin resulteren dat de scripts halverwege stoppen, waardoor de installatie ontregeld raakt. We adviseren sterk om deze functie in te schakelen.",
    "Supported" : "Ondersteund",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Je PHP heeft geen FreeType ondersteuning. Dit zal leiden tot verminkte profielafbeeldingen en instellingeninterface.",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP lijkt niet goed te zijn ingesteld voor opvragen systeemomgevingsvariabelen. De test met getenv(\"PATH\") gaf een leeg resultaat.",
    "PHP modules" : "PHP modules",
    "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "De PHP OPcache is niet geladen.  Voor betere prestaties adviseren we die te laden in je php.ini instellingen.",
    "PHP version" : "PHP versie",
    "Secure" : "Beveiligd",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "De alleen-lezen config is ingeschakeld. Dit voorkomt het via de webinterface wijzigen van verschillende instellingen. Bovendien moet het bestand voor elke aanpassing handmatig op beschrijfbaar worden ingesteld.",
    "Architecture" : "Architectuur",
    "64-bit" : "64-bit",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Je database draait niet met \"READ COMMITTED\" transactie-isolatie niveau. Dit kan problemen opleveren als er meerdere acties tegelijkertijd worden uitgevoerd.",
    "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Profielfoto, volledige naam, e-mailadres, telefoonnummer, adres, website, Twitter, organisatie, rol, kop, biografie en of je profiel is ingeschakeld",
    "Nextcloud settings" : "Nextcloud instellingen",
    "Task:" : "Taak:",
    "Here you can decide which group can access certain sections of the administration settings." : "Hier kun je beslissen welke groep toegang heeft tot bepaalde onderdelen van de beheerders instellingen.",
    "None" : "Geen",
    "Unable to modify setting" : "Kan instelling niet aanpassen",
    "Allow apps to use the Share API" : "Apps toestaan de Share API te gebruiken",
    "Allow resharing" : "Toestaan doordelen",
    "Allow sharing with groups" : "Sta delen met groepen toe",
    "Restrict users to only share with users in their groups" : "Laat gebruikers alleen delen met andere gebruikers in hun groepen",
    "Allow users to share via link and emails" : "Sta gebruikers toe om te delen via een link en e-mail",
    "Allow public uploads" : "Sta publieke uploads toe",
    "Always ask for a password" : "Vraag altijd naar een wachtwoord",
    "Enforce password protection" : "Dwing wachtwoordbeveiliging af",
    "Set default expiration date for shares" : "Instellen standaard vervaldatum voor deellinks",
    "Enforce expiration date" : "Het kiezen van een vervaldatum verplichten",
    "Set default expiration date for shares to other servers" : "Instellen standaard vervaldatum voor deellink naar andere servers",
    "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "Als automatisch aanvullen \"dezelfde groep\" en \"telefoonnummer integratie\" zijn ingeschakeld, is een overeenkomst in een van beide voldoende om de gebruiker te tonen.",
    "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Automatisch aanvullen toestaan bij het invoeren van de volledige naam of het e-mailadres (ontbrekende overeenkomst in het telefoonboek negeren en deel uitmaken van dezelfde groep)",
    "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Toon disclaimer tekst op de publieke link upload pagina (alleen getoond wanneer de bestandslijst verborgen is)",
    "This text will be shown on the public link upload page when the file list is hidden." : "Deze tekst wordt getoond op de openbare link uploadpagina als het bestandsoverzicht is verborgen.",
    "Default share permissions" : "Standaard deelmachtigingen",
    "Two-Factor Authentication" : "Tweetrapsauthenticatie",
    "Enforce two-factor authentication" : "Forceer het gebruik van tweetrapsauthenticatie",
    "Limit to groups" : "Beperk tot groepen",
    "Enforcement of two-factor authentication can be set for certain groups only." : "Het forceren van het gebruik van tweetrapsauthenticatie kan alleen voor bepaalde groepen worden ingesteld.",
    "Two-factor authentication is enforced for all members of the following groups." : "Tweetrapsauthenticatie wordt geforceerd voor alle leden van de volgende groepen.",
    "Enforced groups" : "Afgedwongen groepen",
    "Two-factor authentication is not enforced for members of the following groups." : "Tweetrapsauthenticatie wordt niet geforceerd voor leden van de volgende groepen.",
    "Excluded groups" : "Uitgesloten groepen",
    "Save changes" : "Wijzigingen bewaren",
    "Update to {update}" : "Update naar {update}",
    "Remove" : "Verwijderen",
    "Disable" : "Uitschakelen",
    "Featured" : "Aanbevolen",
    "This app is supported via your current Nextcloud subscription." : "Deze app wordt ondersteund via je huidige Nextcloud abonnement.",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Aanbevolen apps worden ontwikkeld door en binnen de community. Ze bieden centrale functionaliteit en zijn klaar voor productie.",
    "All apps are up-to-date." : "Alle apps zijn up-to-date.",
    "Icon" : "Pictogram",
    "Name" : "Naam",
    "Version" : "Versie",
    "Level" : "Niveau",
    "Actions" : "Acties",
    "Results from other categories" : "Resultaten van andere categorieën",
    "No apps found for your version" : "Geen apps gevonden voor jouw versie",
    "Disable all" : "Alles uitschakelen",
    "_%n app has an update available_::_%n apps have an update available_" : ["Voor %n app is een update beschikbaar","Voor %n apps is een update beschikbaar"],
    "Loading" : "Laden",
    "Description" : "Omschrijving",
    "Details" : "Details",
    "All" : "Alle",
    "Limit app usage to groups" : "Beperk appgebruik tot groepen",
    "No results" : "Geen resultaten",
    "Update to {version}" : "Update naar {version}",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Deze app heeft geen minimum Nextcloud versie toegewezen gekregen. In de toekomst wordt dit wordt een fout.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Deze app heeft geen maximum Nextcloud versie toegewezen gekregen. In de toekomst wordt dit wordt een fout.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Deze app kan niet worden geïnstalleerd, omdat de volgende afhankelijkheden niet zijn ingevuld:",
    "Author" : "Auteur",
    "Categories" : "Categorieën",
    "Resources" : "Bronnen",
    "Documentation" : "Documentatie",
    "Report a bug" : "Rapporteer een fout",
    "Request feature" : "Vraag functionaliteit aan",
    "Ask questions or discuss" : "Stel vragen of discussieer",
    "Rate" : "Beoordelen",
    "View in store" : "Bekijken in store",
    "Visit website" : "Bezoek website",
    "Admin documentation" : "Beheerdocumentatie",
    "Developer documentation" : "Ontwikkelaarsdocumentatie",
    "Changelog" : "Lijst van veranderingen",
    "Marked for remote wipe" : "Aangemerkt voor wissen op afstand",
    "Device settings" : "Apparaatinstellingen",
    "Allow filesystem access" : "Toestaan toegang bestandssysteem",
    "Rename" : "Hernoemen",
    "Revoke" : "Intrekken",
    "Wipe device" : "Apparaat wissen",
    "Revoking this token might prevent the wiping of your device if it has not started the wipe yet." : "Intrekken van deze token kan het wissen van uw apparaat voorkomen als het nog niet is begonnen met wissen.",
    "Google Chrome for Android" : "Google Chrome voor Android",
    "{productName} iOS app" : "{productName} iOS app",
    "{productName} Android app" : "{productName} Android app",
    "{productName} Talk for iOS" : "{productName} Talk for iOS",
    "{productName} Talk for Android" : "{productName} Talk for Android",
    "This session" : "Huidige sessie",
    "Device" : "Apparaat",
    "Last activity" : "Laatste activiteit",
    "Devices & sessions" : "Apparaten & sessies",
    "Web, desktop and mobile clients currently logged in to your account." : "Web, desktop en mobiele clients die momenteel zijn ingelogd op je account.",
    "App name" : "Appnaam",
    "Create new app password" : "Creëer een nieuw app wachtwoord",
    "Error while creating device token" : "Fout bij creëren apparaat-token",
    "Login" : "Login",
    "Password" : "Wachtwoord",
    "Show QR code for mobile apps" : "Toon QR code voor mobiele apps",
    "Could not copy app password. Please copy it manually." : "Kon app wachtwoord niet kopiëren. Kopieer het handmatig.",
    "Last job execution ran {time}. Something seems wrong." : "Laatste taakuitvoering liep {time}. Er lijkt iets fout gegaan.",
    "Last job ran {relativeTime}." : "Laatste taak liep {relativeTime}.",
    "AJAX" : "AJAX",
    "Webcron" : "Webcron",
    "Use system cron service to call the cron.php file every 5 minutes." : "Gebruik de systeemcron service om cron.php elke 5 minuten aan te roepen.",
    "Profile" : "Profiel",
    "Enable" : "Inschakelen",
    "Server-side encryption" : "Server-side versleuteling",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Server-side versleuteling maakt het mogelijk om bestanden te versleutelen die worden geüploaded. Dit betekent wel enig prestatieverlies, dus schakel het alleen in als het nodig is.",
    "Enable server-side encryption" : "Server-side versleuteling inschakelen",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Als versleuteling is ingeschakeld, worden alle geüploade bestanden vanaf dat moment versleuteld opgeslagen op de server.  Het is alleen mogelijk om de versleuteling later uit te schakelen als de actieve versleutelingsmodule dit ondersteunt en aan alle pré-condities (mn de ingestelde herstelsleutel) wordt voldaan.",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Versleuteling alleen gerandeert geen beveiliging van het systeem. Lees de documentatie voor meer achtergrond over de werking van de crypto app an de relevante use cases.",
    "Be aware that encryption always increases the file size." : "Let erop dat versleuteling de bestandsomvang altijd laat toenemen.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Het is altijd verstandig om regelmatig backups van je bestanden te maken. Zorg ervoor dat je in geval van versleuteling ook de cryptosleutel met je gegevens backupt.",
    "This is the final warning: Do you really want to enable encryption?" : "Dit is de laatste waarschuwing: Wil je versleuteling echt inschakelen?",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Er is geen cryptomodule geladen, activeer een cryptomodule in het appmenu",
    "Select default encryption module:" : "Selecteer de standaard cryptomodule:",
    "Cancel" : "Annuleren",
    "Confirm" : "Bevestigen",
    "Submit" : "Verwerken",
    "Rename group" : "Hernoem groep",
    "Remove group" : "Groep verwijderen",
    "Current password" : "Huidig wachtwoord",
    "New password" : "Nieuw wachtwoord",
    "Change password" : "Wijzig wachtwoord",
    "Picture provided by original account" : "Afbeelding is verstrekt door originele account.",
    "Your biography" : "Jouw biografie",
    "You are a member of the following groups:" : "Je bent lid van de volgende groepen:",
    "Your full name" : "Je volledige naam",
    "Primary email for password reset and notifications" : "Primair e-mailadres voor wachtwoordherstel en meldingen",
    "Email options" : "E-mail-opties",
    "Remove primary email" : "Verwijder primair e-mailadres",
    "Delete email" : "Verwijder e-mailadres",
    "This address is not confirmed" : "Dit adres is niet bevestigd",
    "Unset as primary email" : "Verwijder instelling als primaire e-mail",
    "Set as primary email" : "Instellen als primair e-mailadres",
    "Additional email address {index}" : "Extra e-mailadres {index}",
    "Unable to delete primary email address" : "Kan primair e-mailadres niet verwijderen",
    "Unable to update primary email address" : "Kan primair e-mailadres niet updaten",
    "Unable to add additional email address" : "Kan extra e-mailadres niet toevoegen",
    "Unable to update additional email address" : "Kan extra e-mailadres niet updaten",
    "Unable to delete additional email address" : "Kan extra e-mailadres niet verwijderen",
    "No email address set" : "Geen e-mailadres opgegeven",
    "Your headline" : "Jouw hoofdlijn",
    "Languages" : "Talen",
    "Help translate" : "Help met vertalen",
    "Unable to update language" : "Kan taal niet updaten",
    "No language set" : "Geen taal ingesteld",
    "Week starts on {firstDayOfWeek}" : "Week begint op {firstDayOfWeek}",
    "Your organisation" : "Jouw organisatie",
    "Your phone number" : "Je telefoonnummer",
    "Edit your Profile visibility" : "Wijzig je Profiel zichtbaarheid",
    "Unable to update profile enabled state" : "Kan profiel-inschakelstatus niet updaten",
    "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "De meer restrictieve de instelling van de zichtbaarheidsscope wordt gerespecteerd in je Profiel. Bijvoorbeeld als je zichtbaarheid is ingesteld op \"Zichtbaar voor iedereen\" en de scope is ingesteld op \"Privé\" wordt \"Privé\" gerespecteerd.",
    "Unable to update visibility of {displayId}" : "Kan zichtbaarheid van {displayId} niet updaten",
    "Your role" : "Jouw rol",
    "Your website" : "Je website",
    "Add additional email" : "Toevoegen extra e-mailadres",
    "Add" : "Toevoegen",
    "Create" : "Maak",
    "Change" : "Pas aan",
    "Delete" : "Verwijder",
    "Reshare" : "Doordelen",
    "Loading accounts …" : "Laden van accounts …",
    "Default language" : "Standaardtaal",
    "Common languages" : "Gebruikelijke talen",
    "Other languages" : "Andere talen",
    "Password change is disabled because the master key is disabled" : "Wachtwoordwijziging is uitgeschakeld omdat de hoofdsleutel is uitgeschakeld",
    "New account" : "Nieuw account",
    "Display name" : "Weergavenaam",
    "Email" : "E-mailadres",
    "Quota" : "Limieten",
    "Language" : "Taal",
    "Avatar" : "Avatar",
    "Group admin for" : "Groepsbeheerder voor",
    "Storage location" : "Opslag locatie",
    "Last login" : "Laatste login",
    "Account actions" : "Accountacties",
    "{size} used" : "{size} gebruikt",
    "Delete account" : "Account verwijderen",
    "Resend welcome email" : "Verstuur welkomst-e-mail opnieuw",
    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "In het geval van een verloren apparaat of het verlaten van de organisatie, kan dit op afstand de Nextcloud-gegevens wissen van alle apparaten die zijn gekoppeld aan {userid}. Werkt alleen als de apparaten zijn verbonden met het internet.",
    "Remote wipe of devices" : "Op afstand leegmaken toestellen",
    "Wipe {userid}'s devices" : "Wis {userid}'s toestel",
    "Fully delete {userid}'s account including all their personal files, app data, etc." : "Verwijder {userid}'s account volledig, inclusief alle persoonlijke bestanden, app data, etc.",
    "Account deletion" : "Accountverwijdering",
    "Delete {userid}'s account" : "Verwijderen {userid}'s account",
    "Welcome mail sent!" : "Welkomst-e-mail verstuurd!",
    "Done" : "Klaar",
    "Edit" : "Bewerken",
    "Visibility" : "Zichtbaarheid",
    "Show storage path" : "Tonen opslagpad",
    "Show last login" : "Toon laatste inlog",
    "Sorting" : "Sorteren",
    "Send email" : "Verstuur e-mail",
    "Defaults" : "Standaard",
    "Default quota" : "Standaard quota",
    "Select default quota" : "Selecteer standaardquotum",
    "Passwordless authentication requires a secure connection." : "Inloggen zonder wachtwoord vereist een beveiligde verbinding.",
    "Add WebAuthn device" : "WebAuthn-apparaat toevoegen",
    "Please authorize your WebAuthn device." : "Autoriseer je WebAuthn toestel.",
    "Adding your device …" : "Je apparaat toevoegen...",
    "Server error while trying to complete WebAuthn device registration" : "Serverfout tijdens registratie van het WebAuthn apparaat",
    "Unnamed device" : "Naamloos apparaat",
    "Passwordless Authentication" : "Inloggen zonder wachtwoord",
    "Set up your account for passwordless authentication following the FIDO2 standard." : "Stel voor je account wachtwoordloze authenticatie in volgens de FIDO2 standaard.",
    "No devices configured." : "Geen apparaten geconfigureerd.",
    "The following devices are configured for your account:" : "De volgende apparaten zijn ingesteld voor je account:",
    "Your browser does not support WebAuthn." : "Je browser ondersteunt WebAuthn niet.",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Als beheerder kun je gedetailleerde regels voor delen instellen. Bekijk de documentatie voor meer informatie.",
    "You need to enable the File sharing App." : "Je dient de File sharing App in te schakelen",
    "Admins" : "Beheerders",
    "Group name" : "Groepsnaam",
    "Sending…" : "Versturen...",
    "Email sent" : "E-mail verzonden",
    "Location" : "Locatie",
    "Profile picture" : "Profielafbeelding",
    "About" : "Over",
    "Full name" : "Volledige naam",
    "Additional email" : "Extra e-mailadres",
    "Headline" : "Hoofdlijn",
    "Organisation" : "Organisatie",
    "Phone number" : "Telefoonnummer",
    "Role" : "Rol",
    "Website" : "Website",
    "Profile visibility" : "Profiel zichtbaarheid",
    "Locale" : "Regionale instellingen",
    "Not available as this property is required for core functionality including file sharing and calendar invitations" : "Niet beschikbaar omdat deze eigenschap benodigd is voor de basisfunctionaliteit inclusief bestandsdeling en kalender uitnodigingen",
    "Your apps" : "Jouw apps",
    "Active apps" : "Ingeschakelde apps",
    "Disabled apps" : "Uitgeschakelde apps",
    "Updates" : "Updates",
    "App bundles" : "App bundels",
    "Featured apps" : "Aanbevolen apps",
    "Show to everyone" : "Laat zien aan iedereen",
    "Hide" : "Verberg",
    "Download and enable" : "Downloaden en inschakelen",
    "The app will be downloaded from the App Store" : "De app zal worden gedownload van de App Store",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Deze is niet aangeduid als compatibel met jouw versie van Nextcloud. Als je verdergaat, zal je de app kunnen installeren. Let op dat de app misschien niet werkt zoals verwacht.",
    "Never" : "Nooit",
    "An error occurred during the request. Unable to proceed." : "Er is een fout opgetreden tijdens het verzoek. Kan niet doorgaan.",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "De app is ingeschakeld maar moet worden geüpdate. Je wordt over 5 seconden doorgeleid naar de updatepagina.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Fout: Deze app kan niet ingeschakeld worden, omdat die de server onstabiel maakt",
    "Do you really want to wipe your data from this device?" : "Weet je zeker dat je de gegevens van dit apparaat wilt wissen?",
    "Confirm wipe" : "Bevestig wissen",
    "Error while wiping the device with the token" : "Fout tijdens het wissen van het apparaat met de token",
    "Error while updating device token name" : "Fout tijdens bijwerken device tokennaam",
    "Error while updating device token scope" : "Fout tijdens bijwerken device tokenscope",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Er waren te veel aanvragen afkomstig uit uw netwerk. Probeer later opnieuw of contacteer de beheerder als dat niet correct is.",
    "Error" : "Fout",
    "Forum" : "Forum",
    "Legal notice" : "Juridische bepalingen",
    "Privacy policy" : "Privacybeleid",
    "SSL" : "SSL",
    "Open documentation" : "Open documentatie",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Het is belangrijk deze server zo in te stellen dat er ook e-mails verstuurd kunnen worden om wachtwoord resets en meldingen bijvoorbeeld te versturen.",
    "Send mode" : "Verstuurmodus",
    "Encryption" : "Versleuteling",
    "Sendmail mode" : "Sendmail modus",
    "From address" : "Afzenderadres",
    "Server address" : "Server adres",
    "Port" : "Poort",
    "Authentication" : "Authenticatie",
    "Authentication required" : "Authenticatie vereist",
    "Credentials" : "Inloggegevens",
    "SMTP Password" : "SMTP wachtwoord",
    "Save" : "Bewaar",
    "Test and verify email settings" : "Test en controleer de e-mailinstellingen",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Voor beveiliging en prestaties van je server is het belangrijk dat alles goed is geconfigureerd. Om je hierbij te helpen doen we paar automatische controles. Bekijk de gerelateerde documentatie voor meer informatie.",
    "All checks passed." : "Alle controles geslaagd",
    "There are some errors regarding your setup." : "Er zitten foutjes in je configuratie.",
    "There are some warnings regarding your setup." : "Er zijn waarschuwingen over je configuratie.",
    "Checking for system and security issues." : "Controleren op systeem- en beveiligingsproblemen.",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Lees de <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installatie-handleiding ↗</a> goed door en controleer <a href=\"%2$s\">de logs</a> op fouten en waarschuwingen.",
    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Controleer de beveiliging van je Nextcloud via <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">onze securityscan ↗</a>.",
    "Reasons to use Nextcloud in your organization" : "Redenen om Nextcloud te gebruiken in jouw organisatie",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Ontwikkeld door de {communityopen}Nextcloud community{linkclose}, de {githubopen}broncode{linkclose} is gelicenseerd onder de {licenseopen}AGPL{linkclose}.",
    "Like our Facebook page" : "Vind onze Facebook pagina leuk",
    "Follow us on Mastodon" : "Volg ons op Mastodon",
    "Check out our blog" : "Lees ons blog",
    "Subscribe to our newsletter" : "Abonneer jezelf op onze nieuwsbrief",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Deze community release van Nextcloud wordt niet ondersteund en instant meldingen zijn niet beschikbaar",
    "Use a second factor besides your password to increase security for your account." : "Gebruik een tweede factor naast je wachtwoord om de beveiliging van je account te verhogen. ",
    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Als u toepassingen van derden gebruikt om met Nextcloud te verbinden, zorg er dan voor om voor elke app een wachtwoord te maken en te configureren voordat \"tweede factor authenticatie\" wordt geactiveerd.",
    "No user supplied" : "Geen gebruiker opgegeven",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Voer een beheerdersherstelwachtwoord in, anders zullen alle gebruikersgegevens verloren gaan",
    "Invalid user" : "Ongeldige gebruiker",
    "Your username is: %s" : "Je gebruikersnaam is: %s",
    "Logged in user must be a subadmin" : "Ingelogde gebruiker moet een subbeheerder zijn",
    "A background job is pending that checks for user imported SSL certificates. Please check back later." : "Er is een achtergrondtaak in bezig die controleert op door de gebruiker geïmporteerde SSL-certificaten. Kom later terug.",
    "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "Er zijn enkele door gebruikers geïmporteerde SSL-certificaten aanwezig, die niet meer worden gebruikt met Nextcloud 21. Ze kunnen op de opdrachtregel worden geïmporteerd via het commando \"occ security:certificates:import\". De paden binnen de gegevensdirectory worden hieronder weergegeven.",
    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "De database mist een paar indexen. Omdat het toevoegen van indexen op grote tabellen veel tijd kan kosten, zijn ze niet automatisch gecreëerd. Door het draaien van \"occ db:add-missing-indices\" kunnen deze indexen handmatig worden toegevoegd terwijl de server blijft draaien.  Als de indexen zijn toegevoegd, zullen opvragingen op die tabellen veel sneller plaatsvinden.",
    "Exclude groups from sharing" : "Sta bepaalde groepen niet toe om te delen",
    "These groups will still be able to receive shares, but not to initiate them." : "Deze groepen kunnen gedeelde mappen en bestanden ontvangen, maar kunnen zelf niks delen.",
    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Tweetrapsauthenticatie kan worden afgedwongen voor alle gebruikers en specifieke groepen. Als ze geen tweetrapsprovider hebben ingesteld, dan kunnen ze niet inloggen in het systeem.",
    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Wanneer groepen worden geselecteerd/uitgezonderd, geldt de volgende logica om te bepalen of voor een gebruiker 2FA wordt afgedwongen: Als geen groepen zijn geselecteerd, is 2FA voor iedereen ingeschakeld, behalve voor leden van de uitgezonderde groepen. Als groepen zijn geselecteerd is 2FA is ingeschakeld voor alle leden ervan. Als een gebruiker lid is van zowel een geselecteerde als uitgezonderde groep, krijgt de geselecteerde voorrang en wordt 2FA afgedwongen.",
    "{license}-licensed" : "{license}-gelicenseerd",
    "Username" : "Gebruikersnaam",
    "Execute one task with each page loaded. Use case: Single user instance." : "Een taak uitvoeren bij het laden van iedere pagina. Use case: voor een enkele gebruiker.",
    "Enable or disable profile by default for new users." : "Profiel standaard in- of uitschakelen voor nieuwe gebruikers.",
    "Additional emails" : "Extra e-mailadressen",
    "Enable Profile" : "Schakel Profiel in",
    "New user" : "Nieuwe gebruiker",
    "User backend" : "Backend gebruiker",
    "You do not have permissions to see the details of this user" : "Je hebt niet de machtigingen om de details van deze gebruiekr te zien",
    "Add user to group" : "Toevoegen gebruiker aan groep",
    "Set user as admin for" : "Maak gebruiker beheerder voor",
    "Select user quota" : "Selecteer gebruikersquotum",
    "Delete user" : "Verwijder gebruiker",
    "Wipe all devices" : "Wis alle toestellen",
    "Disable user" : "Gebruiker uitschakelen",
    "Enable user" : "Inschakelen gebruiker",
    "Toggle user actions menu" : "Omschakelen gebruikersactiemenu",
    "Show user backend" : "Toon backend gebruiker",
    "Name your device" : "Geef je apparaat een naam",
    "Server error while trying to add WebAuthn device" : "Serverfout tijdens het toevoegen van WebAuthn apparaat",
    "by {author}\n{license}" : "door {author}\n{license}",
    "Active users" : "Actieve gebruikers",
    "Disabled users" : "Uitgeschakelde gebruikers",
    "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions" : "Niet beschikbaar omdat het publiceren van gebruikersdata aan de lookup server niet toegestaan is, neem contact op met je beheerder als je vragen hebt",
    "Show to logged in users only" : "Laat alleen zien aan ingelogde gebruikers",
    "SMTP Username" : "SMTP gebruikersnaam",
    "Follow us on Twitter" : "Volg ons op Twitter"
},
"nplurals=2; plural=(n != 1);");
